@@ -17,5 +17,5 @@ class LockAdmin(admin.ModelAdmin):
     time_remaining.short_description = _("Time Remaining")
     time_remaining.admin_order_field = "expire_time"
 
-if settings.DJANGO_DB_LOCK_AUTO_REGISTER_ADMIN:
+if settings.DJANGO_DB_LOCK_AUTO_REGISTER_ADMIN and settings.DJANGO_DB_LOCK_AUTO_REGISTER_MODEL:
     admin.site.register(Lock, LockAdmin)
